import { Interfaces } from '@oclif/core';
import { Org } from '@salesforce/core';
import { FileResponse } from '@salesforce/source-deploy-retrieve';
import { Duration } from '@salesforce/kit';
import { SourceTracking } from '@salesforce/source-tracking';
import { SfCommand } from '@salesforce/sf-plugins-core';
import { DeleteSourceJson } from '../../../utils/types.js';
export declare class Source extends SfCommand<DeleteSourceJson> {
    static readonly summary: string;
    static readonly description: string;
    static readonly examples: string[];
    static readonly aliases: string[];
    static readonly deprecateAliases = true;
    static readonly requiresProject = true;
    static readonly flags: {
        'api-version': Interfaces.OptionFlag<string | undefined, Interfaces.CustomOptions>;
        loglevel: Interfaces.OptionFlag<string | undefined, Interfaces.CustomOptions>;
        'target-org': Interfaces.OptionFlag<Org, Interfaces.CustomOptions>;
        'check-only': Interfaces.BooleanFlag<boolean>;
        wait: Interfaces.OptionFlag<Duration, Interfaces.CustomOptions>;
        tests: Interfaces.OptionFlag<string[] | undefined, Interfaces.CustomOptions>;
        'test-level': Interfaces.OptionFlag<import("../../../utils/types.js").TestLevel, Interfaces.CustomOptions>;
        'no-prompt': Interfaces.BooleanFlag<boolean>;
        metadata: Interfaces.OptionFlag<string[] | undefined, Interfaces.CustomOptions>;
        'source-dir': Interfaces.OptionFlag<string[] | undefined, Interfaces.CustomOptions>;
        'track-source': Interfaces.BooleanFlag<boolean>;
        'force-overwrite': Interfaces.BooleanFlag<boolean>;
        verbose: Interfaces.BooleanFlag<boolean>;
    };
    protected fileResponses: FileResponse[] | undefined;
    protected tracking: SourceTracking | undefined;
    private components;
    private mixedDeployDelete;
    private stashPath;
    private flags;
    private org;
    private componentSet;
    private deployResult;
    run(): Promise<DeleteSourceJson>;
    protected preChecks(): Promise<void>;
    protected delete(): Promise<void>;
    /**
     * Checks the response status to determine whether the delete was successful.
     */
    protected resolveSuccess(): Promise<void>;
    protected formatResult(): Promise<DeleteSourceJson>;
    private maybeUpdateTracking;
    private deleteFilesLocally;
    private moveToManifest;
    private handlePrompt;
    /**
     * Check if any conflicts exist in a specific component set.
     * If conflicts exist, this will output the table and throw
     */
    private filterConflictsByComponentSet;
}
